/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file console_widget.h Types related to the console widgets. */

#ifndef WIDGETS_CONSOLE_WIDGET_H
#define WIDGETS_CONSOLE_WIDGET_H

/** Widgets of the #IConsoleWindow class. */
enum ConsoleWidgets : WidgetID {
	WID_C_BACKGROUND, ///< Background of the console.
};

#endif /* WIDGETS_CONSOLE_WIDGET_H */
